==> kubernetes-model-autoscaling-6.5.1-sources.jar: io/fabric8/kubernetes/api/model/autoscaling/v2/ResourceMetricStatusFluentImpl.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v2;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ResourceMetricStatusFluentImpl<A extends ResourceMetricStatusFluent<A>> extends BaseFluent<A> implements ResourceMetricStatusFluent<A>{
  public ResourceMetricStatusFluentImpl() {
  }
  public ResourceMetricStatusFluentImpl(ResourceMetricStatus instance) {
    this.withCurrent(instance.getCurrent()); 
    this.withName(instance.getName()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private MetricValueStatusBuilder current;
  private String name;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildCurrent instead.
   * @return The buildable object.
   */
  @Deprecated
  public MetricValueStatus getCurrent() {
    return this.current!=null ?this.current.build():null;
  }
  public MetricValueStatus buildCurrent() {
    return this.current!=null ?this.current.build():null;
  }
  public A withCurrent(MetricValueStatus current) {
    _visitables.get("current").remove(this.current);
    if (current!=null){ this.current= new MetricValueStatusBuilder(current); _visitables.get("current").add(this.current);} else { this.current = null; _visitables.get("current").remove(this.current); } return (A) this;
  }
  public Boolean hasCurrent() {
    return this.current != null;
  }
  public ResourceMetricStatusFluent.CurrentNested<A> withNewCurrent() {
    return new ResourceMetricStatusFluentImpl.CurrentNestedImpl();
  }
  public ResourceMetricStatusFluent.CurrentNested<A> withNewCurrentLike(MetricValueStatus item) {
    return new ResourceMetricStatusFluentImpl.CurrentNestedImpl(item);
  }
  public ResourceMetricStatusFluent.CurrentNested<A> editCurrent() {
    return withNewCurrentLike(getCurrent());
  }
  public ResourceMetricStatusFluent.CurrentNested<A> editOrNewCurrent() {
    return withNewCurrentLike(getCurrent() != null ? getCurrent(): new MetricValueStatusBuilder().build());
  }
  public ResourceMetricStatusFluent.CurrentNested<A> editOrNewCurrentLike(MetricValueStatus item) {
    return withNewCurrentLike(getCurrent() != null ? getCurrent(): item);
  }
  public String getName() {
    return this.name;
  }
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  public Boolean hasName() {
    return this.name != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ResourceMetricStatusFluentImpl that = (ResourceMetricStatusFluentImpl) o;
    if (current != null ? !current.equals(that.current) :that.current != null) return false;
    if (name != null ? !name.equals(that.name) :that.name != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(current,  name,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (current != null) { sb.append("current:"); sb.append(current + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class CurrentNestedImpl<N> extends MetricValueStatusFluentImpl<ResourceMetricStatusFluent.CurrentNested<N>> implements ResourceMetricStatusFluent.CurrentNested<N>,Nested<N>{
    CurrentNestedImpl(MetricValueStatus item) {
      this.builder = new MetricValueStatusBuilder(this, item);
    }
    CurrentNestedImpl() {
      this.builder = new MetricValueStatusBuilder(this);
    }
    MetricValueStatusBuilder builder;
    public N and() {
      return (N) ResourceMetricStatusFluentImpl.this.withCurrent(builder.build());
    }
    public N endCurrent() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-autoscaling-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/autoscaling/v2/ResourceMetricStatusFluentImpl.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v2;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ResourceMetricStatusFluentImpl<A extends ResourceMetricStatusFluent<A>> extends BaseFluent<A> implements ResourceMetricStatusFluent<A>{
  public ResourceMetricStatusFluentImpl() {
  }
  public ResourceMetricStatusFluentImpl(ResourceMetricStatus instance) {
    if (instance != null) {
      this.withCurrent(instance.getCurrent());
      this.withName(instance.getName());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private MetricValueStatusBuilder current;
  private String name;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildCurrent instead.
   * @return The buildable object.
   */
  @Deprecated
  public MetricValueStatus getCurrent() {
    return this.current!=null ?this.current.build():null;
  }
  public MetricValueStatus buildCurrent() {
    return this.current!=null ?this.current.build():null;
  }
  public A withCurrent(MetricValueStatus current) {
    _visitables.get("current").remove(this.current);
    if (current!=null){ this.current= new MetricValueStatusBuilder(current); _visitables.get("current").add(this.current);} else { this.current = null; _visitables.get("current").remove(this.current); } return (A) this;
  }
  public Boolean hasCurrent() {
    return this.current != null;
  }
  public ResourceMetricStatusFluentImpl.CurrentNested<A> withNewCurrent() {
    return new ResourceMetricStatusFluentImpl.CurrentNestedImpl();
  }
  public ResourceMetricStatusFluentImpl.CurrentNested<A> withNewCurrentLike(MetricValueStatus item) {
    return new ResourceMetricStatusFluentImpl.CurrentNestedImpl(item);
  }
  public ResourceMetricStatusFluentImpl.CurrentNested<A> editCurrent() {
    return withNewCurrentLike(getCurrent());
  }
  public ResourceMetricStatusFluentImpl.CurrentNested<A> editOrNewCurrent() {
    return withNewCurrentLike(getCurrent() != null ? getCurrent(): new MetricValueStatusBuilder().build());
  }
  public ResourceMetricStatusFluentImpl.CurrentNested<A> editOrNewCurrentLike(MetricValueStatus item) {
    return withNewCurrentLike(getCurrent() != null ? getCurrent(): item);
  }
  public String getName() {
    return this.name;
  }
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  public Boolean hasName() {
    return this.name != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ResourceMetricStatusFluentImpl that = (ResourceMetricStatusFluentImpl) o;
    if (!java.util.Objects.equals(current, that.current)) return false;

    if (!java.util.Objects.equals(name, that.name)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(current,  name,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (current != null) { sb.append("current:"); sb.append(current + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class CurrentNestedImpl<N> extends MetricValueStatusFluentImpl<ResourceMetricStatusFluentImpl.CurrentNested<N>> implements ResourceMetricStatusFluentImpl.CurrentNested<N>,Nested<N>{
    CurrentNestedImpl(MetricValueStatus item) {
      this.builder = new MetricValueStatusBuilder(this, item);
    }
    CurrentNestedImpl() {
      this.builder = new MetricValueStatusBuilder(this);
    }
    MetricValueStatusBuilder builder;
    public N and() {
      return (N) ResourceMetricStatusFluentImpl.this.withCurrent(builder.build());
    }
    public N endCurrent() {
      return and();
    }
    
  }
  
}
